---
gitea: none
include_toc: true
---


[Return to the list of application services.](../README.md)
# nsd

## Synopsis


[NSD, an authoritative DNS name server.](https://www.nlnetlabs.nl/projects/nsd/about/)

## Example

Zone names are provided as examples. Think about adapting with the value of provider_zone in configuration file.

```
nsd:
  applicationservice: nsd
  zones_name:
    - localdns
  values:
    general.dns_zone.nsd_zones:
      - subdomain.example.net
```

## Basic variables

### General

#### Serveur DNS

| Parameter                                                                                                                                                                                                                           | Comment                                        |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------|
| **[general.dns_server.nsd_allowed_client_cidr](dictionaries/20_nsd.xml)**<br/>multiple<br/>**Type:** [`network_cidr`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Clients autorisés à interroger le serveur DNS. |
| **[general.dns_server.nsd_resolver](dictionaries/20_nsd.xml)**<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                           | Nom de domaine du résolveur DNS associé.       |

#### Zone DNS

| Parameter                                                                                                                                                                                                                    | Comment                                           |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------|
| **[general.dns_zone.nsd_zones](dictionaries/20_nsd.xml)**<br/>mandatory, multiple<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Zones DNS.<br/>**Example:** subdomain.example.net |

#### Zone DNS reverse

This family is a leadership.

| Parameter                                                                                                                                                                                                                         | Comment                            |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------|
| **[general.dns_reverses.nsd_reverse_network](dictionaries/20_nsd.xml)**<br/>multiple<br/>**Type:** [`network_cidr`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Réseau pour la résolution reverse. |

### Nsd

#### Zone *suffix value*

This a dynamic family generated from the variable "general.dns_zone.nsd_zones".

##### Nom d'hôte pour *suffix value*

This family is a leadership.

| Parameter                                                                                                                                                                                                                                                               | Comments                                                                     |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------|
| **[nsd.nsd_zone_*suffix value*.hostname_*suffix value*.hostname_*suffix value*](extras/nsd/00_nsd.xml)**<br/>mandatory, multiple<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Nom d'hôte pour *suffix value*.                                              |
| **[nsd.nsd_zone_*suffix value*.hostname_*suffix value*.type_*suffix value*](extras/nsd/00_nsd.xml)**<br/>mandatory<br/>**Type:** [`choice`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)               | Type pour *suffix value*.<br/>**Choices:**<br/>- `A` ← default<br/>- `CNAME` |
| **[nsd.nsd_zone_*suffix value*.hostname_*suffix value*.ip_*suffix value*](extras/nsd/00_nsd.xml)**<br/>mandatory<br/>**Type:** [`ip`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                     | Adresse IP a renvoyer pour *suffix value*.                                   |
| **[nsd.nsd_zone_*suffix value*.hostname_*suffix value*.cname_*suffix value*](extras/nsd/00_nsd.xml)**<br/>mandatory<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)          | Nom de domaine a renvoyer pour *suffix value*.                               |

| Parameter                                                                                                                                                                                                                                     | Comments                                           |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------|
| **[nsd.nsd_zone_*suffix value*.ns_*suffix value*](extras/nsd/00_nsd.xml)**<br/>mandatory, multiple<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Nom des serveurs de nom de la zone *suffix value*. |



## Requirements services

### Mandatories

- [LocalDNS](../README.LocalDNS.md): DNS forwarder for local domain name.

### Optionals

- [Journald](../README.Journald.md): Concentrate journal messages on one host.

## Dependances

- [base-fedora-37](../base-fedora-37/README.md): Base information of a Fedora 37.
  - [base-fedora](../base-fedora/README.md): Base information of a Fedora.
    - [systemd](../systemd/README.md): Systemd, a system and service manager.
      - [base-machine](../base-machine/README.md): Base information for a machine.
        - [base](../base/README.md): Base of all application services.
        - [dns-local](../dns-local/README.md): DNS client with access to local zones.
        - [pki-tls](../pki-tls/README.md): Autosign PKI or Let's encrypt support for TLS certificates.
      - [journald](../journald/README.md): Journald.
      - [resolved](../resolved/README.md): Resolved.

## Used by

[nsd-local](../nsd-local/README.md)
