---
gitea: none
include_toc: true
---


[Return to the list of application services.](../README.md)
# odoo

## Synopsis


[Odoo, an ERP and CRM.](https://www.odoo.com/fr)

## Example

Zone names are provided as examples. Think about adapting with the value of provider_zone in configuration file.

```
odoo:
  applicationservice: odoo
  zones_name:
    - ldap
    - localdns
    - oauth2
    - postgresql
    - reverseproxy
    - smtp
  values:
    general.revprox.revprox_client.revprox_client_external_domainnames:
      - service.example.net
    general.odoo.odoo_admin_email: johndoe@example.net
    general.odoo.odoo_company_name: ACME
    general.odoo.odoo_company_street: John Doe Street
    general.odoo.odoo_company_city: Dijon
    general.odoo.odoo_company_zip: '21000'
    general.odoo.odoo_company_vat: FR 99999999999
    general.odoo.odoo_company_registry: 999 999 999 00099
    general.odoo.odoo_company_email: johndoe@example.net
    general.odoo.odoo_company_website: https://example.net
    general.odoo.odoo_company_logo: /home/jdoe/logo.png
    general.odoo.odoo_company_footer: foot
```

## Basic variables

### General

#### Reverse proxy

##### Clients configuration

This family is a leadership.

| Parameter                                                                                                                                                                                                                                                                       | Comment                                                            |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------|
| **[general.revprox.revprox_client.revprox_client_external_domainnames](dictionaries/21_revprox_client.xml)**<br/>mandatory, multiple<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Service external domain name.<br/>**Example:** service.example.net |
| **[general.revprox.revprox_client.revprox_client_location](dictionaries/21_revprox_client.xml)**<br/>mandatory<br/>**Type:** [`filename`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                         | URI to route request to the correct service.<br/>**Default:** /    |

#### Odoo

| Parameter                                                                                                                                                                                                               | Comments                                                                                                         |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------|
| **[general.odoo.odoo_admin_email](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`mail`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)        | Adresse courriel de l'administrateur.<br/>**Example:** johndoe@example.net                                       |
| **[general.odoo.odoo_company_name](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)     | Nom.<br/>**Example:** ACME                                                                                       |
| **[general.odoo.odoo_company_street](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)   | Adresse.<br/>**Example:** John Doe Street                                                                        |
| **[general.odoo.odoo_company_city](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)     | Ville.<br/>**Example:** Dijon                                                                                    |
| **[general.odoo.odoo_company_zip](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)      | Code postal.<br/>**Example:** 21000                                                                              |
| **[general.odoo.odoo_company_vat](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)      | Numéro TVA.<br/>**Example:** FR 99999999999                                                                      |
| **[general.odoo.odoo_company_registry](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Registre de la société.<br/>**Example:** 999 999 999 00099                                                       |
| **[general.odoo.odoo_company_phone](dictionaries/40_odoo.xml)**<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                  | Numéro de téléphone.                                                                                             |
| **[general.odoo.odoo_company_mobile](dictionaries/40_odoo.xml)**<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                 | Numéro de téléphone mobile.                                                                                      |
| **[general.odoo.odoo_company_email](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)    | Adresse courriel.<br/>**Example:** johndoe@example.net                                                           |
| **[general.odoo.odoo_company_website](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)  | Site internet.<br/>**Example:** https://example.net                                                              |
| **[general.odoo.odoo_company_logo](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`filename`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)   | Chemin du logo.<br/>**Example:** /home/jdoe/logo.png                                                             |
| **[general.odoo.odoo_company_footer](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)   | Pied de page des documents.<br/>**Example:** foot                                                                |
| **[general.odoo.odoo_company_layout](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`choice`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)   | Agencement des documents.<br/>**Choices:**<br/>- `standard` ← default<br/>- `bold`<br/>- `boxed`<br/>- `striped` |

## Variables

### General

#### OpenLDAP directory

##### Client

| Parameter                                                                                                                                                                                                              | Comment                                                                       |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------|
| **[general.ldap.client.ldapclient_family](dictionaries/21_ldap-client.xml)**<br/>**Type:** [`unix_user`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Restrict service configuration for a LDAP family.<br/>"all" for all families. |

#### Reverse proxy

##### Clients configuration

This family is a leadership.

| Parameter                                                                                                                                                                                                                                    | Comment                                              |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------|
| **[general.revprox.revprox_client.revprox_client_max_body_size](dictionaries/21_revprox_client.xml)**<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | The maximum allowed size of the client request body. |

#### OAuth2 client

| Parameter                                                                                                                                                                                                                            | Comment                                                                                   |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------|
| **[general.oauth2_client.oauth2_client_name](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)        | OAuth2 client name.<br/>**Default:** ERP<br/>**Example:** example                         |
| **[general.oauth2_client.oauth2_client_description](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | OAuth2 client description.<br/>**Default:** ERP Odoo<br/>**Example:** Example description |
| **[general.oauth2_client.oauth2_client_login](dictionaries/30_oauth2_client.xml)**<br/>**Type:** [`web_address`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)       | OAuth2 URL to valid login.                                                                |

##### external

| Parameter                                                                                                                                                                                                                                                 | Comments                                                |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------|
| **[general.oauth2_client.external.oauth2_client_external](dictionaries/40_odoo.xml)**<br/>mandatory, multiple<br/>**Type:** [`web_address`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | OAuth2 client external.<br/>**Default:** *calculated*   |
| **[general.oauth2_client.external.oauth2_client_family](dictionaries/40_odoo.xml)**<br/>mandatory, multiple<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)        | OAuth2 family.<br/>**Default:** <ul><li>users</li></ul> |

| Parameter                                                                                                                                                                                                                         | Comment                                        |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------|
| **[general.oauth2_client.oauth2_client_category](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | OAuth2 category.<br/>**Default:** Entreprise   |
| **[general.oauth2_client.oauth2_client_logo](dictionaries/40_odoo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)     | OAuth2 logo.<br/>**Default:** silique_note.png |



## Variables for expert

### General

#### NGINX

| Parameter                                                                                                                                                                                                                  | Comment                                                                                                        |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------|
| **[general.nginx.nginx_hash_bucket_size](dictionaries/21_nginx.xml)**<br/>mandatory<br/>**Type:** [`choice`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | The bucket size for the server names hash tables.<br/>**Choices:**<br/>- `128` ← default<br/>- `64`<br/>- `32` |
| **[general.nginx.nginx_post_max_size](dictionaries/21_nginx.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)    | The maximum allowed size of the client request body.<br/>This value is in Mb.<br/>**Default:** 32              |

#### Odoo

| Parameter                                                                                                                                                                                                               | Comments                                                                                                                                                                             |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **[general.odoo.odoo_addons](dictionaries/40_odoo.xml)**<br/>mandatory, multiple<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Liste des applications à activer.<br/>**Default:** <ul><li>base</li><li>l10n_fr</li><li>l10n_fr_fec</li><li>account</li><li>hr</li><li>hr_contract</li><li>sale_management</li></ul> |

## Requirements services

### Mandatories

- [LocalDNS](../README.LocalDNS.md): DNS forwarder for local domain name.
- [SMTP](../README.SMTP.md): Create a SMTP relay account and authorize sending email.
- [LDAP](../README.LDAP.md): Create account and connexion to a LDAP server.
- [ReverseProxy](../README.ReverseProxy.md): Register to service to a reverse proxy server.
- [Postgresql](../README.Postgresql.md): Create account and connexion to a PostgreSQL server.
- [OAuth2](../README.OAuth2.md): Remote clients needing to verify OAuth2 account.

### Optionals

- [Journald](../README.Journald.md): Concentrate journal messages on one host.

## Dependances

- [base-debian-bullseye](../base-debian-bullseye/README.md): Base information of a Debian Bulleye server.
  - [base-debian](../base-debian/README.md): Base information of a Debian server.
    - [systemd](../systemd/README.md): Systemd, a system and service manager.
      - [base-machine](../base-machine/README.md): Base information for a machine.
        - [base](../base/README.md): Base of all application services.
        - [dns-local](../dns-local/README.md): DNS client with access to local zones.
        - [pki-tls](../pki-tls/README.md): Autosign PKI or Let's encrypt support for TLS certificates.
      - [journald](../journald/README.md): Journald.
      - [resolved](../resolved/README.md): Resolved.
- [postgresql-client](../postgresql-client/README.md): Application service needs interact with a Postgresql server.
- [reverse-proxy-client](../reverse-proxy-client/README.md): Application service needs interact with a a reverse proxy server.
- [relay-mail-client](../relay-mail-client/README.md): Client SMTP.
- [ldap-client](../ldap-client/README.md): Application service needs interact with a LDAP server.
- [oauth2-client](../oauth2-client/README.md): Application service needs interact with a Oauth2 server.
- [nginx-https](../nginx-https/README.md): Nginx as HTTPS web site.
  - [nginx-common](../nginx-common/README.md): Nginx common configuration.
  - [reverse-proxy-client](../reverse-proxy-client/README.md): Application service needs interact with a a reverse proxy server.
