---
gitea: none
include_toc: true
---


[Return to the list of application services.](../README.md)
# openldap

## Synopsis


[OpenLDAP, the LDAP server.](https://www.openldap.org/)

This service provides a LDAP server.

It is possible to request the creation of users. Those users can be mixed or
classified into families.

Those users will be created and updated. They will never be deleted. The
initial password will be generated but never updated. You can modify them.

Other services may also require automatic user creation.

## Example

Zone names are provided as examples. Think about adapting with the value of provider_zone in configuration file.

```
openldap:
  applicationservice: openldap
  provider_zone: ldap
  zones_name:
    - localdns
```


## Variables

### Accounts

#### Users management

Management of manually created local users. Those users are not classified. This family is a leadership.

| Parameter                                                                                                                                                                                                                  | Comments                                                                                          |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------|
| **[accounts.users.ldap_user_mail](extras/accounts/00_account.xml)**<br/>multiple<br/>**Type:** [`mail`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)      | Email address.<br/>An user is identify by his email address.<br/>**Example:** johndoe@example.net |
| **[accounts.users.ldap_user_aliases](extras/accounts/00_account.xml)**<br/>multiple<br/>**Type:** [`mail`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)   | Emails aliases.<br/>**Example:** jdoe@example.net                                                 |
| **[accounts.users.ldap_user_uid](extras/accounts/00_account.xml)**<br/>mandatory<br/>**Type:** [`unix_user`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Account name.<br/>**Example:** jdoe                                                               |
| **[accounts.users.ldap_user_gn](extras/accounts/00_account.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)     | Given name.<br/>**Example:** John                                                                 |
| **[accounts.users.ldap_user_sn](extras/accounts/00_account.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)     | Surname.<br/>**Example:** Doe                                                                     |

| Parameter                                                                                                                                                                                                      | Comment                                                                                                                            |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------|
| **[accounts.families](extras/accounts/00_account.xml)**<br/>multiple<br/>**Type:** [`unix_user`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Families to create.<br/>Users can be classified into families. This variable contains all the names of the families to be created. |

#### Management of family *suffix value*

This a dynamic family generated from the variable "accounts.families".

##### Users management for the family *suffix value*

Management of manually created users. Those users are classified in a family. This family is a leadership.

| Parameter                                                                                                                                                                                                                                                                      | Comments                                                                                                                       |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------|
| **[accounts.family_*suffix value*.users_*suffix value*.ldap_user_mail_*suffix value*](extras/accounts/00_account.xml)**<br/>multiple<br/>**Type:** [`mail`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)      | Email address for the family *suffix value*.<br/>An user is identify by his email address.<br/>**Example:** johndoe@family.net |
| **[accounts.family_*suffix value*.users_*suffix value*.ldap_user_aliases_*suffix value*](extras/accounts/00_account.xml)**<br/>multiple<br/>**Type:** [`mail`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)   | Emails aliases for the family *suffix value*.<br/>**Example:** jdoe@family.net                                                 |
| **[accounts.family_*suffix value*.users_*suffix value*.ldap_user_uid_*suffix value*](extras/accounts/00_account.xml)**<br/>mandatory<br/>**Type:** [`unix_user`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Account name for the family *suffix value*.<br/>**Example:** jdoe                                                              |
| **[accounts.family_*suffix value*.users_*suffix value*.ldap_user_gn_*suffix value*](extras/accounts/00_account.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)     | Given name for the family *suffix value*.<br/>**Example:** John                                                                |
| **[accounts.family_*suffix value*.users_*suffix value*.ldap_user_sn_*suffix value*](extras/accounts/00_account.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)     | Surname for the family *suffix value*.<br/>**Example:** Doe                                                                    |

## Variables for expert

### General

#### LDAP

| Parameter                                                                                                                                                                                                                             | Comment                                                                                                                                                                                                                   |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **[general.ldap.ldap_schemas](dictionaries/21_openldap-server.xml)**<br/>mandatory, multiple<br/>**Type:** [`filename`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Additional LDAP schemas.<br/>**Default:** <ul><li>/etc/openldap/schema/cosine.ldif</li><li>/etc/openldap/schema/inetorgperson.ldif</li><li>/etc/openldap/schema/nis.ldif</li><li>/etc/openldap/schema/misc.ldif</li></ul> |

##### Limits

| Parameter                                                                                                                                                                                                                          | Comment                                                                        |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------|
| **[general.ldap.limits.ldap_loglevel](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)  | Log level.<br/>**Default:** 0                                                  |
| **[general.ldap.limits.ldap_sizelimit](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Nombre maximum d'entrées à retourner lors d'une requête.<br/>**Default:** 5000 |
| **[general.ldap.limits.ldap_timelimit](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Temps de réponse maximum à une requête (en secondes).<br/>**Default:** 3600    |

##### DB environment

| Parameter                                                                                                                                                                                                                                      | Comment                                                                                            |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------|
| **[general.ldap.db_environment.db_cache_size_g](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)    | Quantité de Giga-octets à utiliser pour le cache HDB.<br/>**Default:** 0                           |
| **[general.ldap.db_environment.db_cache_size_o](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)    | Quantité d'octets à utiliser pour le cache HDB.<br/>**Default:** 268435456                         |
| **[general.ldap.db_environment.db_cache_chunks](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)    | Nombre de fichiers ou écrire le cache HDB.<br/>**Default:** 1                                      |
| **[general.ldap.db_environment.db_log_region_max](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)  | Quantité de fichier de cache mis en cache mémoire.<br/>**Default:** 262144                         |
| **[general.ldap.db_environment.db_log_max](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)         | Quantité d'informations de journalisation conservé jusqu'à rotation.<br/>**Default:** 10485760     |
| **[general.ldap.db_environment.db_log_bsize](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)       | Quantité d'informations de journalisation du cache reporté sur le disque.<br/>**Default:** 2097152 |
| **[general.ldap.db_environment.db_log_directory](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`filename`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Répertoire de conservation des informations de journalisation.<br/>**Default:** /srv/openldap/log  |
| **[general.ldap.db_environment.db_lk_max_objects](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)  | Nombre d'objet qui peuvent être verrouillés simultanément .<br/>**Default:** 5000                  |
| **[general.ldap.db_environment.db_lk_max](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)          | Nombre de verrous maximal.<br/>**Default:** 5000                                                   |
| **[general.ldap.db_environment.db_lk_max_lockers](dictionaries/21_openldap-server.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)  | Nombre de verroulleur maximal.<br/>**Default:** 5000                                               |



## Requirements services

### Mandatories

- [LocalDNS](../README.LocalDNS.md): DNS forwarder for local domain name.

### Optionals

- [Journald](../README.Journald.md): Concentrate journal messages on one host.

## Dependances

- [base-fedora-37](../base-fedora-37/README.md): Base information of a Fedora 37.
  - [base-fedora](../base-fedora/README.md): Base information of a Fedora.
    - [systemd](../systemd/README.md): Systemd, a system and service manager.
      - [base-machine](../base-machine/README.md): Base information for a machine.
        - [base](../base/README.md): Base of all application services.
        - [dns-local](../dns-local/README.md): DNS client with access to local zones.
        - [pki-tls](../pki-tls/README.md): Autosign PKI or Let's encrypt support for TLS certificates.
      - [journald](../journald/README.md): Journald.
      - [resolved](../resolved/README.md): Resolved.

## Useful for services

- [dovecot](../dovecot/README.md): Postfix and Dovecot as mail servers (IMAP and submission).
- [lemonldap](../lemonldap/README.md): LemonLDAP, a Web Single Sign On and Access Management.
- [nextcloud](../nextcloud/README.md): Nextcloud, Online collaboration platform.
- [odoo](../odoo/README.md): Odoo, an ERP and CRM.
- [piwigo](../piwigo/README.md): Piwigo, a photo management software.
- [roundcube](../roundcube/README.md): Roundcube, a webmail.
