---
gitea: none
include_toc: true
---


[Return to the list of application services.](../README.md)
# peertube

## Synopsis


[Peertube, a federated (ActivityPub) video streaming platform.](https://www.openldap.org/)

## Example

Zone names are provided as examples. Think about adapting with the value of provider_zone in configuration file.

```
peertube:
  applicationservice: peertube
  zones_name:
    - externaldns
    - oauth2
    - postgresql
    - redis
    - reverseproxy
    - smtp
  values:
    general.revprox.revprox_client.revprox_client_external_domainnames:
      - service.example.net
    general.peertube.peertube_admin_email: john.doe@example.net
```

## Basic variables

### General

#### Reverse proxy

##### Clients configuration

This family is a leadership.

| Parameter                                                                                                                                                                                                                                                                       | Comment                                                            |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------|
| **[general.revprox.revprox_client.revprox_client_external_domainnames](dictionaries/21_revprox_client.xml)**<br/>mandatory, multiple<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Service external domain name.<br/>**Example:** service.example.net |
| **[general.revprox.revprox_client.revprox_client_location](dictionaries/30_peertube.xml)**<br/>mandatory<br/>**Type:** [`filename`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                               | URI to route request to the correct service.<br/>**Default:** /    |

#### peertube

| Parameter                                                                                                                                                                                                                    | Comments                                                                             |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------|
| **[general.peertube.peertube_admin_email](dictionaries/30_peertube.xml)**<br/>mandatory<br/>**Type:** [`mail`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Adresse courriel de l'administrateur Peertube.<br/>**Example:** john.doe@example.net |

## Variables

### General

#### Reverse proxy

##### Clients configuration

This family is a leadership.

| Parameter                                                                                                                                                                                                                                            | Comment                                                                   |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------|
| **[general.revprox.revprox_client.revprox_client_max_body_size](dictionaries/30_peertube.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | The maximum allowed size of the client request body.<br/>**Default:** 12G |

#### OAuth2 client

| Parameter                                                                                                                                                                                                                                | Comment                                                                                                                  |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------|
| **[general.oauth2_client.oauth2_client_name](dictionaries/30_peertube.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)        | OAuth2 client name.<br/>**Default:** Vidéo<br/>**Example:** example                                                      |
| **[general.oauth2_client.oauth2_client_description](dictionaries/30_peertube.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | OAuth2 client description.<br/>**Default:** Plateforme de partage de vidéo Peertube<br/>**Example:** Example description |
| **[general.oauth2_client.oauth2_client_login](dictionaries/30_oauth2_client.xml)**<br/>**Type:** [`web_address`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)           | OAuth2 URL to valid login.                                                                                               |

##### external

| Parameter                                                                                                                                                                                                                                                     | Comments                                              |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------|
| **[general.oauth2_client.external.oauth2_client_external](dictionaries/30_peertube.xml)**<br/>mandatory, multiple<br/>**Type:** [`web_address`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | OAuth2 client external.<br/>**Default:** *calculated* |
| **[general.oauth2_client.external.oauth2_client_family](dictionaries/30_oauth2_client.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)             | OAuth2 family.<br/>**Default:** users                 |

| Parameter                                                                                                                                                                                                                             | Comment                                           |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------|
| **[general.oauth2_client.oauth2_client_category](dictionaries/30_peertube.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | OAuth2 category.<br/>**Default:** Réseaux sociaux |
| **[general.oauth2_client.oauth2_client_logo](dictionaries/30_peertube.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)     | OAuth2 logo.<br/>**Default:** silique_video.png   |

#### peertube

| Parameter                                                                                                                                                                                                                            | Comments                                                                                                                                               |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------|
| **[general.peertube.peertube_short_description](dictionaries/30_peertube.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Description courte de l'instance.<br/>**Default:** PeerTube, an ActivityPub-federated video streaming platform using P2P directly in your web browser. |
| **[general.peertube.peertube_description](dictionaries/30_peertube.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)       | Description de l'instance.<br/>**Default:** Welcome to this PeerTube instance!                                                                         |

## Variables for expert

### General

#### NGINX

| Parameter                                                                                                                                                                                                                  | Comment                                                                                                        |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------|
| **[general.nginx.nginx_hash_bucket_size](dictionaries/21_nginx.xml)**<br/>mandatory<br/>**Type:** [`choice`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | The bucket size for the server names hash tables.<br/>**Choices:**<br/>- `128` ← default<br/>- `64`<br/>- `32` |
| **[general.nginx.nginx_post_max_size](dictionaries/21_nginx.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)    | The maximum allowed size of the client request body.<br/>This value is in Mb.<br/>**Default:** 32              |



## Requirements services

### Mandatories

- [SMTP](../README.SMTP.md): Create a SMTP relay account and authorize sending email.
- [ReverseProxy](../README.ReverseProxy.md): Register to service to a reverse proxy server.
- [Postgresql](../README.Postgresql.md): Create account and connexion to a PostgreSQL server.
- [OAuth2](../README.OAuth2.md): Remote clients needing to verify OAuth2 account.
- [ExternalDNS](../README.ExternalDNS.md): DNS forwarder for all DNS zones.
- [Redis](../README.Redis.md): Create account and connexion to a Redis server.

### Optionals

- [Journald](../README.Journald.md): Concentrate journal messages on one host.

## Dependances

- [base-fedora-38](../base-fedora-38/README.md): Base information of a Fedora 38.
  - [base-fedora](../base-fedora/README.md): Base information of a Fedora.
    - [systemd](../systemd/README.md): Systemd, a system and service manager.
      - [base-machine](../base-machine/README.md): Base information for a machine.
        - [base](../base/README.md): Base of all application services.
        - [dns-local](../dns-local/README.md): DNS client with access to local zones.
        - [pki-tls](../pki-tls/README.md): Autosign PKI or Let's encrypt support for TLS certificates.
      - [journald](../journald/README.md): Journald.
      - [resolved](../resolved/README.md): Resolved.
- [dns-external](../dns-external/README.md): DNS client with resolution on all zones (especially outside).
- [postgresql-client](../postgresql-client/README.md): Application service needs interact with a Postgresql server.
- [relay-mail-client](../relay-mail-client/README.md): Client SMTP.
- [reverse-proxy-client](../reverse-proxy-client/README.md): Application service needs interact with a a reverse proxy server.
- [redis-client](../redis-client/README.md): Application service needs interact with a Redis server.
  - [redis-common](../redis-common/README.md): Redis, an in-memory data structure store.
- [nginx-https](../nginx-https/README.md): Nginx as HTTPS web site.
  - [nginx-common](../nginx-common/README.md): Nginx common configuration.
  - [reverse-proxy-client](../reverse-proxy-client/README.md): Application service needs interact with a a reverse proxy server.
- [oauth2-client](../oauth2-client/README.md): Application service needs interact with a Oauth2 server.
