---
gitea: none
include_toc: true
---


[Return to the list of application services.](../README.md)
# piwigo

## Synopsis


[Piwigo, a photo management software.](http://piwigo.org/)

## Example

Zone names are provided as examples. Think about adapting with the value of provider_zone in configuration file.

```
piwigo:
  applicationservice: piwigo
  zones_name:
    - ldap
    - localdns
    - mariadb
    - oauth2
    - redis
    - reverseproxy
    - smtp
  values:
    general.revprox.revprox_client.revprox_client_external_domainnames:
      - service.example.net
    general.piwigo.piwigo_admin_email: admin@example.net
    general.piwigo.users.piwigo_users:
      - jdoe
    general.piwigo.users.piwigo_email:
      '0': johndoe@example.net
```

## Basic variables

### General

#### Reverse proxy

##### Clients configuration

This family is a leadership.

| Parameter                                                                                                                                                                                                                                                                       | Comment                                                            |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------|
| **[general.revprox.revprox_client.revprox_client_external_domainnames](dictionaries/21_revprox_client.xml)**<br/>mandatory, multiple<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Service external domain name.<br/>**Example:** service.example.net |
| **[general.revprox.revprox_client.revprox_client_location](dictionaries/21_revprox_client.xml)**<br/>mandatory<br/>**Type:** [`filename`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                         | URI to route request to the correct service.<br/>**Default:** /    |

#### Piwigo

| Parameter                                                                                                                                                                                                              | Comment                                                                         |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------|
| **[general.piwigo.piwigo_admin_email](dictionaries/31_piwigo.xml)**<br/>mandatory<br/>**Type:** [`mail`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Adresse courriel de l'administrateur Piwigo.<br/>**Example:** admin@example.net |

##### Piwigo users

This family is a leadership.

| Parameter                                                                                                                                                                                                                             | Comments                                               |
|---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------|
| **[general.piwigo.users.piwigo_users](dictionaries/31_piwigo.xml)**<br/>mandatory, multiple<br/>**Type:** [`unix_user`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Utilisateur ayant un album.<br/>**Example:** jdoe      |
| **[general.piwigo.users.piwigo_email](dictionaries/31_piwigo.xml)**<br/>mandatory<br/>**Type:** [`mail`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                | Adresse courriel.<br/>**Example:** johndoe@example.net |

## Variables

### General

#### OpenLDAP directory

##### Client

| Parameter                                                                                                                                                                                                              | Comment                                                                       |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------|
| **[general.ldap.client.ldapclient_family](dictionaries/21_ldap-client.xml)**<br/>**Type:** [`unix_user`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Restrict service configuration for a LDAP family.<br/>"all" for all families. |

#### Reverse proxy

##### Clients configuration

This family is a leadership.

| Parameter                                                                                                                                                                                                                                    | Comment                                              |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------|
| **[general.revprox.revprox_client.revprox_client_max_body_size](dictionaries/21_revprox_client.xml)**<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | The maximum allowed size of the client request body. |

#### OAuth2 client

| Parameter                                                                                                                                                                                                                              | Comment                                                                                                      |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|--------------------------------------------------------------------------------------------------------------|
| **[general.oauth2_client.oauth2_client_name](dictionaries/31_piwigo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)        | OAuth2 client name.<br/>**Default:** Album<br/>**Example:** example                                          |
| **[general.oauth2_client.oauth2_client_description](dictionaries/31_piwigo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | OAuth2 client description.<br/>**Default:** Album photographique Piwigo<br/>**Example:** Example description |
| **[general.oauth2_client.oauth2_client_login](dictionaries/30_oauth2_client.xml)**<br/>**Type:** [`web_address`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)         | OAuth2 URL to valid login.                                                                                   |

##### external

| Parameter                                                                                                                                                                                                                                                          | Comments                                              |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------|
| **[general.oauth2_client.external.oauth2_client_external](dictionaries/30_oauth2_client.xml)**<br/>mandatory, multiple<br/>**Type:** [`web_address`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | OAuth2 client external.<br/>**Default:** *calculated* |
| **[general.oauth2_client.external.oauth2_client_family](dictionaries/30_oauth2_client.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                  | OAuth2 family.<br/>**Default:** users                 |

| Parameter                                                                                                                                                                                                                           | Comment                                         |
|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------|
| **[general.oauth2_client.oauth2_client_category](dictionaries/31_piwigo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | OAuth2 category.<br/>**Default:** Diffusion     |
| **[general.oauth2_client.oauth2_client_logo](dictionaries/31_piwigo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)     | OAuth2 logo.<br/>**Default:** silique_image.png |

#### Piwigo

| Parameter                                                                                                                                                                                                          | Comment                                                 |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------|
| **[general.piwigo.piwigo_title](dictionaries/31_piwigo.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Titre de l'album.<br/>**Default:** Album photographique |



## Variables for expert

### General

#### PHP

Paramètrage avancé de PHP.

| Parameter                                                                                                                                                                                                                  | Comment                                                                                                                 |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-------------------------------------------------------------------------------------------------------------------------|
| **[general.php.php_post_max_size](dictionaries/20_php.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)          | Maximum size of POST data that PHP will accept.<br/>Value in Mb.<br/>**Default:** 32                                    |
| **[general.php.php_upload_max_filesize](dictionaries/20_php.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)    | Maximum allowed size for uploaded files.<br/>Value in Mb.<br/>**Default:** 16                                           |
| **[general.php.php_max_execution_time](dictionaries/20_php.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)     | Maximum amount of time each script may spend parsing request data.<br/>Value in seconds.<br/>**Default:** 30            |
| **[general.php.php_max_input_time](dictionaries/20_php.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)         | Maximum amount of time each script may spend parsing request data.<br/>Value in seconds.<br/>**Default:** 60            |
| **[general.php.php_memory_limit](dictionaries/20_php.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)           | Maximum amount of memory a script may consume.<br/>Value in Mb.<br/>**Default:** 512                                    |
| **[general.php.php_session_gc_maxlifetime](dictionaries/20_php.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | Data will be seen as 'garbage' and potentially cleaned up after this delay.<br/>Value in seconds.<br/>**Default:** 3600 |

#### NGINX

| Parameter                                                                                                                                                                                                                  | Comment                                                                                                        |
|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------|
| **[general.nginx.nginx_hash_bucket_size](dictionaries/21_nginx.xml)**<br/>mandatory<br/>**Type:** [`choice`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | The bucket size for the server names hash tables.<br/>**Choices:**<br/>- `128` ← default<br/>- `64`<br/>- `32` |
| **[general.nginx.nginx_post_max_size](dictionaries/21_nginx.xml)**<br/>mandatory<br/>**Type:** [`number`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)    | The maximum allowed size of the client request body.<br/>This value is in Mb.<br/>**Default:** 32              |



## Requirements services

### Mandatories

- [LocalDNS](../README.LocalDNS.md): DNS forwarder for local domain name.
- [SMTP](../README.SMTP.md): Create a SMTP relay account and authorize sending email.
- [LDAP](../README.LDAP.md): Create account and connexion to a LDAP server.
- [ReverseProxy](../README.ReverseProxy.md): Register to service to a reverse proxy server.
- [OAuth2](../README.OAuth2.md): Remote clients needing to verify OAuth2 account.
- [Redis](../README.Redis.md): Create account and connexion to a Redis server.
- [MariaDB](../README.MariaDB.md): Create account and connexion to a MariaDB server.

### Optionals

- [Journald](../README.Journald.md): Concentrate journal messages on one host.

## Dependances

- [base-fedora-36](../base-fedora-36/README.md): Base information of a Fedora 36.
  - [base-fedora](../base-fedora/README.md): Base information of a Fedora.
    - [systemd](../systemd/README.md): Systemd, a system and service manager.
      - [base-machine](../base-machine/README.md): Base information for a machine.
        - [base](../base/README.md): Base of all application services.
        - [dns-local](../dns-local/README.md): DNS client with access to local zones.
        - [pki-tls](../pki-tls/README.md): Autosign PKI or Let's encrypt support for TLS certificates.
      - [journald](../journald/README.md): Journald.
      - [resolved](../resolved/README.md): Resolved.
- [mariadb-client](../mariadb-client/README.md): Application service needs interact with a MariaDB server.
- [ldap-client](../ldap-client/README.md): Application service needs interact with a LDAP server.
- [redis-client](../redis-client/README.md): Application service needs interact with a Redis server.
  - [redis-common](../redis-common/README.md): Redis, an in-memory data structure store.
- [oauth2-client](../oauth2-client/README.md): Application service needs interact with a Oauth2 server.
- [relay-mail-client](../relay-mail-client/README.md): Client SMTP.
- [nginx-https](../nginx-https/README.md): Nginx as HTTPS web site.
  - [nginx-common](../nginx-common/README.md): Nginx common configuration.
  - [reverse-proxy-client](../reverse-proxy-client/README.md): Application service needs interact with a a reverse proxy server.
- [php-fpm](../php-fpm/README.md): PHP FPM.
  - [php](../php/README.md): PHP, a popular general-purpose scripting language.
