---
gitea: none
include_toc: true
---


[Return to the list of application services.](../README.md)
# znc

## Synopsis


[ZNC, a bouncer IRC.](https://wiki.znc.in/)

The IRC network bouncer or BNC can detach the client from the actual IRC server, and also from selected channelsp.

## Example

Zone names are provided as examples. Think about adapting with the value of provider_zone in configuration file.

```
znc:
  applicationservice: znc
  zones_name:
    - externaldns
  values:
    general.znc.external_domain_name: irc.example.net
    general.znc.user_name: jdoe
    general.znc.user_password: JD0eP@ss
    general.znc.real_name: John Doe
    general.znc.servers.server_names:
      - irc.oftc.net
    general.znc.servers.password:
      '0': p@ssw0rd
    general.znc.servers.channels:
      '0':
        - example
```

## Basic variables

### General

#### IRC Bouncer ZNC

| Parameter                                                                                                                                                                                                                | Comment                                                                                                                                                                                                                                                                                        |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **[general.znc.external_domain_name](dictionaries/40_znc.xml)**<br/>mandatory<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | External domain name.<br/>**Example:** irc.example.net                                                                                                                                                                                                                                         |
| **[general.znc.znc_crt_provider](dictionaries/40_znc.xml)**<br/>mandatory<br/>**Type:** [`choice`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)         | Type of certificate autority signing external certificate.<br/>The certificate can be self-signed (therefore invalid by default for the client) or obtained via the Let's Encrypt service (generally valid for the client).<br/>**Choices:**<br/>- `self-signed` ← default<br/>- `letsencrypt` |
| **[general.znc.user_name](dictionaries/40_znc.xml)**<br/>mandatory<br/>**Type:** [`unix_user`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)             | IRC and ZNC username.<br/>**Example:** jdoe                                                                                                                                                                                                                                                    |
| **[general.znc.user_password](dictionaries/40_znc.xml)**<br/>mandatory<br/>**Type:** [`password`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)          | ZNC user password.<br/>**Example:** JD0eP@ss                                                                                                                                                                                                                                                   |
| **[general.znc.real_name](dictionaries/40_znc.xml)**<br/>mandatory<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                | Real IRC user name.<br/>**Example:** John Doe                                                                                                                                                                                                                                                  |

##### Serveurs IRC

This family is a leadership.

| Parameter                                                                                                                                                                                                                          | Comments                                       |
|------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|------------------------------------------------|
| **[general.znc.servers.server_names](dictionaries/40_znc.xml)**<br/>mandatory, multiple<br/>**Type:** [`domainname`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable) | IRC domain name.<br/>**Example:** irc.oftc.net |
| **[general.znc.servers.password](dictionaries/40_znc.xml)**<br/>mandatory<br/>**Type:** [`password`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)                 | IR user passwordC.<br/>**Example:** p@ssw0rd   |
| **[general.znc.servers.channels](dictionaries/40_znc.xml)**<br/>mandatory, multiple<br/>**Type:** [`string`](https://forge.cloud.silique.fr/risotto/rougail/src/branch/main/doc/variable/README.md#le-type-de-la-variable)         | IRC channels.<br/>**Example:** example         |



## Requirements services

### Mandatories

- [ExternalDNS](../README.ExternalDNS.md): DNS forwarder for all DNS zones.

### Optionals

- [Journald](../README.Journald.md): Concentrate journal messages on one host.

## Dependances

- [base-fedora-36](../base-fedora-36/README.md): Base information of a Fedora 36.
  - [base-fedora](../base-fedora/README.md): Base information of a Fedora.
    - [systemd](../systemd/README.md): Systemd, a system and service manager.
      - [base-machine](../base-machine/README.md): Base information for a machine.
        - [base](../base/README.md): Base of all application services.
        - [dns-local](../dns-local/README.md): DNS client with access to local zones.
        - [pki-tls](../pki-tls/README.md): Autosign PKI or Let's encrypt support for TLS certificates.
      - [journald](../journald/README.md): Journald.
      - [resolved](../resolved/README.md): Resolved.
- [dns-external](../dns-external/README.md): DNS client with resolution on all zones (especially outside).
